@@ -6,6 +6,7 @@ from urllib import parse as urlparse
 
 import responses  # type: ignore
 
+import abnosql.mocks.mock_azure_auth as auth
 from abnosql.plugins.table.memory import get_table_count
 from abnosql import table
 
@@ -157,6 +158,7 @@ def mock_cosmos(f):
 
     @functools.wraps(f)
     def decorated(*args, **kwargs):
+        auth.mock_auth()
         for method in ['GET', 'POST', 'DELETE', 'PUT', 'PATCH']:
             responses.add_callback(
                 getattr(responses, method),
